package utils

import (
	"context"

	"k8s.io/apimachinery/pkg/types"
	corev1alpha1 "libre.sh/controller/apis/core/v1alpha1"
	"sigs.k8s.io/controller-runtime/pkg/client"
)

type Context struct {
	ctx    context.Context
	client client.Client
	Object corev1alpha1.LibreContext
}

func NewContext(ctx context.Context, client client.Client, namespace string) (Context, error) {
	o, err := GetLibreContext(ctx, client, namespace)
	if err != nil {
		return Context{}, err
	}
	return Context{
		ctx:    ctx,
		client: client,
		Object: o,
	}, nil
}

func (ctx Context) GetS3Provider() *corev1alpha1.S3Provider {
	if ctx.Object.Spec.Providers != nil {
		for _, provider := range ctx.Object.Spec.Providers {
			if provider.Type == corev1alpha1.LibreContextProviderS3Type {
				var provider corev1alpha1.S3Provider
				ctx.client.Get(ctx.ctx, types.NamespacedName{
					Namespace: ctx.Object.Namespace,
					Name:      provider.Name,
				}, &provider)
				return &provider
			}
		}
	}
	return nil
}
